import logging
import re
import os

logger = logging.getLogger(__name__)


def to_camelcase(s):
    s = re.sub(r"(_|-)+", " ", s).title().replace(" ", "").replace("*", "")
    return "".join([s[0].lower(), s[1:]])


def to_snakecase(s):
    return re.sub(r"(?<!^)(?=[A-Z])", "_", s).lower()


def get_value(s):
    if not isinstance(s, str):
        return s

    if s.startswith("file:"):
        filepath = s[len("file:") :]
        logger.debug(f"reading from file '{filepath}'")
        return open(filepath, "r").read().strip()

    if s.startswith("env:"):
        envkey = s.strip()[len("env:") :]
        logger.debug(f"reading from envvar '{envkey}'")
        return os.getenv(envkey)

    logger.debug(f"using original value")
    return s
